Package: grpreg
Title: Regularization Paths for Regression Models with Grouped
        Covariates
Version: 3.0-2
Date: 2016-07-11
Author: Patrick Breheny
Maintainer: Patrick Breheny <patrick-breheny@uiowa.edu>
Depends: R (>= 2.13.0), Matrix
Suggests: grpregOverlap, knitr, survival
VignetteBuilder: knitr
Description: Efficient algorithms for fitting the regularization path of
 linear or logistic regression models with grouped penalties.  This
 includes group selection methods such as group lasso, group MCP, and
 group SCAD as well as bi-level selection methods such as the group
 exponential lasso, the composite MCP, and the group bridge.
BugReports: http://github.com/pbreheny/grpreg/issues
License: GPL-3
NeedsCompilation: yes
Packaged: 2016-07-11 20:21:48 UTC; pbreheny
Repository: CRAN
Date/Publication: 2016-07-11 22:56:52
Built: R 3.4.1; x86_64-w64-mingw32; 2017-08-17 19:40:50 UTC; windows
Archs: x64
