Package: grpreg
Title: Regularization Paths for Regression Models with Grouped
        Covariates
Version: 3.4.0
Date: 2021-07-22
Authors@R: c(
  person("Patrick", "Breheny", role=c("aut","cre"), email="patrick-breheny@uiowa.edu", comment=c(ORCID="0000-0002-0650-1119")),
  person("Yaohui", "Zeng", role="ctb"),
  person("Ryan", "Kurth", role="ctb"))
Depends: R (>= 3.1.0)
Imports: Matrix
Suggests: knitr, rmarkdown, splines, survival, tinytest
VignetteBuilder: knitr
Description: Efficient algorithms for fitting the regularization path of linear
  regression, GLM, and Cox regression models with grouped penalties.  This
  includes group selection methods such as group lasso, group MCP, and
  group SCAD as well as bi-level selection methods such as the group
  exponential lasso, the composite MCP, and the group bridge.  For more
  information, see Breheny and Huang (2009) <doi:10.4310/sii.2009.v2.n3.a10>,
  Huang, Breheny, and Ma (2012) <doi:10.1214/12-sts392>, Breheny and Huang
  (2015) <doi:10.1007/s11222-013-9424-2>, and Breheny (2015)
  <doi:10.1111/biom.12300>, or visit the package homepage
  <https://pbreheny.github.io/grpreg/>.
BugReports: https://github.com/pbreheny/grpreg/issues
License: GPL-3
URL: https://pbreheny.github.io/grpreg/,
        https://github.com/pbreheny/grpreg
LazyData: TRUE
RoxygenNote: 7.1.1
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2021-07-26 16:29:43 UTC; pbreheny
Author: Patrick Breheny [aut, cre] (<https://orcid.org/0000-0002-0650-1119>),
  Yaohui Zeng [ctb],
  Ryan Kurth [ctb]
Maintainer: Patrick Breheny <patrick-breheny@uiowa.edu>
Repository: CRAN
Date/Publication: 2021-07-26 18:10:02 UTC
Built: R 4.0.5; x86_64-w64-mingw32; 2021-07-26 21:41:24 UTC; windows
Archs: x64
