import("graphics")
import("grDevices")
import("stats")
import("utils")
importFrom("Matrix", "bdiag")
useDynLib(grpreg, .registration=TRUE)
export(AUC)
export(cv.grpreg)
export(cv.grpsurv)
export(expand_spline)
export(gBridge)
export(gen_nonlinear_data)
export(grpreg)
export(grpsurv)
export(plot_spline)
export(select)
S3method(AUC, cv.grpsurv)
S3method(coef, grpreg)
S3method(coef, cv.grpreg)
S3method(logLik, grpreg)
S3method(logLik, grpsurv)
S3method(plot, grpreg)
S3method(plot, cv.grpreg)
S3method(plot, grpsurv.func)
S3method(predict, grpreg)
S3method(predict, cv.grpreg)
S3method(predict, grpsurv)
S3method(print, summary.cv.grpreg)
S3method(residuals, grpreg)
S3method(select, grpreg)
S3method(summary, cv.grpreg)
